summaryrefslogtreecommitdiffstats
path: root/kmail/kmsender.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kmail/kmsender.cpp
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmsender.cpp')
-rw-r--r--kmail/kmsender.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/kmsender.cpp b/kmail/kmsender.cpp
index 987e4928..86e931cf 100644
--- a/kmail/kmsender.cpp
+++ b/kmail/kmsender.cpp
@@ -363,9 +363,9 @@ void KMSender::doSendMsg()
// Disable the emitting of msgAdded signal, because the message is taken out of the
// current folder (outbox) and re-added, to make filter actions changing the message
// work. We don't want that to screw up message counts.
- if ( mCurrentMsg->tqparent() ) mCurrentMsg->tqparent()->quiet( true );
+ if ( mCurrentMsg->parent() ) mCurrentMsg->parent()->quiet( true );
const int processResult = kmkernel->filterMgr()->process(mCurrentMsg,KMFilterMgr::Outbound);
- if ( mCurrentMsg->tqparent() ) mCurrentMsg->tqparent()->quiet( false );
+ if ( mCurrentMsg->parent() ) mCurrentMsg->parent()->quiet( false );
// 0==processed ok, 1==no filter matched, 2==critical error, abort!
switch (processResult) {
@@ -401,13 +401,13 @@ void KMSender::doSendMsg()
break;
}
seStatusByLink( mCurrentMsg );
- if (mCurrentMsg->tqparent() && !imapSentFolder) {
+ if (mCurrentMsg->parent() && !imapSentFolder) {
// for speed optimization, this code assumes that mCurrentMsg is the
- // last one in it's tqparent folder; make sure that's really the case:
- assert( mCurrentMsg->tqparent()->find( mCurrentMsg )
- == mCurrentMsg->tqparent()->count() - 1 );
+ // last one in it's parent folder; make sure that's really the case:
+ assert( mCurrentMsg->parent()->find( mCurrentMsg )
+ == mCurrentMsg->parent()->count() - 1 );
// unGet this message:
- mCurrentMsg->tqparent()->unGetMsg( mCurrentMsg->tqparent()->count() -1 );
+ mCurrentMsg->parent()->unGetMsg( mCurrentMsg->parent()->count() -1 );
}
mCurrentMsg = 0;